@@ -4,9 +4,10 @@ from kafka.errors import KafkaError
 import threading
 import logging
 import os
-
+import ssl
 class KNativeKafkaProducer(threading.Thread):
     daemon = True
+    ssl.match_hostname = lambda cert, hostname: True
     def __init__(self,topic:str):
 
         """
@@ -74,4 +75,13 @@ class KNativeKafkaProducer(threading.Thread):
             self.producer.flush(30)
         except KafkaError as e:
             self.logger.error(f'Kafka Error {e}')
-            raise Exception(f'Kafka Error {e}')
\ No newline at end of file
+            raise Exception(f'Kafka Error {e}')
+
+    def flush(self):
+        if self.producer: 
+            self.producer.flush()
+
+    def close(self):
+        if self.producer: 
+            self.producer.close()
+            self.producer=None
